#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Indicator;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Strategy;
#endregion


namespace NinjaTrader.Strategy
{                                                           
    [Description("ADX Breakouts - The ADX signal line goes up whenever volatility increases. When ADX gets over 40, it shows especially strong breakout price action in progress.")]
	public class ADXBreakoutStrategy : Strategy
    {
        #region Variables
        private int aDXPeriod = 14; // Default setting for ADXPeriod
        private int aDXBO = 40; // Default setting for ADX Breakout Value
		private double pntAbvDlyHi = 0.5;
		private double aDXLineValueUpper = 40;
		private double aDXLineValueLower = 20;
		private double cH = 0;
		private int pointStopLoss = 2;
		private bool signalValid = true;
		private Color arrowColor = Color.LimeGreen;
		private String aDXBreakoutSignalMessage = @"ADX Breakout";
        #endregion

       
        protected override void Initialize()
        {
			Add(ADXBreakoutsIndicator(aDXBO,aDXBreakoutSignalMessage,aDXPeriod,arrowColor, pntAbvDlyHi));
			Add(ADX(ADXPeriod));
			Add(VolumeUpDown());
            SetTrailStop(pointStopLoss);
			ExitOnClose = false;
			ADX(ADXPeriod).Lines[0].Value = 20;
			ADX(ADXPeriod).Lines[1].Value = 40;		
        }

        
        protected override void OnBarUpdate()
        {
			if(Position.MarketPosition == MarketPosition.Flat)
				SetTrailStop(pointStopLoss);
			
			if (CurrentBar < aDXPeriod) return;	
				
            // Condition for ADX Breakout Entry Signals
            if (ADX(ADXPeriod)[0] > ADXBO && Close[0] >= CurrentDayOHL().CurrentHigh[1] + pntAbvDlyHi && signalValid)
			{
				EnterLong(DefaultQuantity,"Breakout Entry");
				SetTrailStop(CalculationMode.Ticks, pointStopLoss*(Instrument.MasterInstrument.PointValue/(Instrument.MasterInstrument.PointValue * TickSize)));
				signalValid = false;
			}
			
			if(!signalValid && ADX(ADXPeriod)[0] < ADXBO)
			{
				signalValid = true;
			}
		}	

        #region Properties
        [Description("Value for ADX Period ")]
        [GridCategory("Parameters")]
        public int ADXPeriod
        {
            get { return aDXPeriod; }
            set { aDXPeriod = Math.Max(1, value); }
        }

        [Description("Value for ADX")]
        [GridCategory("Parameters")]
        public int ADXBO
        {
            get { return aDXBO; }
            set { aDXBO = Math.Max(1, value); }
        }
		
		[Description("Point value above daily high")]
        [GridCategory("Parameters")]
        public double PntAbvDlyHi
        {
            get { return pntAbvDlyHi; }
            set { pntAbvDlyHi = Math.Max(1, value); }
        }
		
		[Description("Point value for stop loss")]
        [GridCategory("Parameters")]
        public int PointStopLoss
        {
            get { return pointStopLoss; }
            set { pointStopLoss = Math.Max(1, value); }
        }
		
		[Description("Value for ADX Lower Line")]
        [GridCategory("Parameters")]
        public double ADXLineValueLower
        {
            get { return aDXLineValueLower; }
            set { aDXLineValueLower = Math.Max(1, value); }
        }
		
		[Description("Value for ADX Upper Line")]
        [GridCategory("Parameters")]
        public double ADXLineValueUpper
        {
            get { return aDXLineValueUpper; }
            set { aDXLineValueUpper = Math.Max(1, value); }
        }
		
		[Description("ADX Breakout Signal Message")]
        [GridCategory("Parameters")]
        public string ADXBreakoutSignalMessage
        {
            get { return aDXBreakoutSignalMessage; }
            set { aDXBreakoutSignalMessage = value; }
        }
		
		[XmlIgnore()]
		[Description("Color for Breakout Entry Signal Arrow")]
        [GridCategory("Parameters")]
        public Color ArrowColor
        {
            get { return arrowColor; }
            set { arrowColor = value; }
        }
		
		[Browsable(false)]
		public string arrowColorSerialize
		{
			get { return NinjaTrader.Gui.Design.SerializableColor.ToString(arrowColor); }
			set { arrowColor = NinjaTrader.Gui.Design.SerializableColor.FromString(value); }
		}
        #endregion
    }
}
